#PBS -l nodes=4:ppn=16:xeon2650v2:mell03
#PBS -o stdout.log
#PBS -e stderr.log
#PBS -l walltime=2:15:0
#PBS -m ae

from ase.io import read
from gpaw import GPAW, Mixer, FermiDirac, PoissonSolver, LCAO
from gpaw.xc.libvdwxc import vdw_df_cx
from gpaw.mpi import world
from gpaw.utilities import h2gpts
from gpaw.utilities.timing import ParallelTimer

system = read('blasphemous_monstrosity.xyz')
system.center(vacuum=5.0)
system.pbc = 1

options = {1: (1, 1, 1), # test
           2: (2, 1, 1), # test
           4: (2, 2, 1), # test 
           8: (4, 2, 2), # test
           16: (4, 4, 4), # 1
           32: (4, 8, 16), # 2
           48: (8, 6, 4), # 3
           64: (8, 8, 16), # 4
           96: (12, 8, 4), # 6
           128: (8, 16, 4)} # 8

na, nb, band = options[world.size]
assert na * nb == world.size

idiv = 32
nblock = 64
nbands = '105%'
if world.size < 16:
    idiv = 8
    nbands='150%'
    nblock = 4

calc = GPAW(mode=LCAO('scipy'),
            basis={'H': 'sz(dzp)',
                   'N': 'szp(dzp)',
                   'S': 'szp(dzp)',
                   'C': 'szp(dzp)',
                   'Au': 'pvalence.dz'},
            nbands=nbands,
            txt='gpaw.txt',
            gpts=h2gpts(0.18, system.get_cell(), idiv=idiv),
            timer=ParallelTimer(),
            mixer=Mixer(0.05, 5, 200.0),
            parallel=dict(sl_default=(na, nb, nblock), band=band,
                          augment_grids=True),
            poissonsolver=PoissonSolver(relax='J'),
            occupations=FermiDirac(0.1),
            xc=vdw_df_cx())
def stopcalc():
    calc.scf.converged = True
calc.attach(stopcalc, 15)

system.calc = calc
system.get_potential_energy()
